| rsmp_all_test | R Documentation |
Utility for use with a pretrained learner in importance methods which support it
rsmp_all_test(task)
task |
(mlr3::Task) |
Note that the resulting Resampling will have an empty train set, making it useless for any other purpose than the use with a pretrained learner.
mlr3::Resampling with an empty train_set and a single test_set identical to all of the given Task.
library(mlr3)
# Create custom task from some data.frame
custom_task <- as_task_regr(mtcars, target = "mpg")
# Create matching Resampling with all-test data
resampling_custom <- rsmp_all_test(custom_task)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.