| xplainfi-package | R Documentation |
Provides a consistent interface for common feature importance methods as described in Ewald et al. (2024) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/978-3-031-63797-1_22")}, including permutation feature importance (PFI), conditional and relative feature importance (CFI, RFI), leave one covariate out (LOCO), and Shapley additive global importance (SAGE), as well as feature sampling mechanisms to support conditional importance methods.
Maintainer: Lukas Burk cran@lukasburk.de (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.