FeatureSampler: Feature Sampler Class

FeatureSamplerR Documentation

Feature Sampler Class

Description

Base class for implementing different sampling strategies for feature importance methods like PFI and CFI

Public fields

task

(mlr3::Task) Original task.

label

(character(1)) Name of the sampler.

feature_types

(character()) Feature types supported by the sampler. Will be checked against the provided mlr3::Task to ensure compatibility.

param_set

(paradox::ParamSet) Parameter set for the sampler.

Methods

Public methods


Method new()

Creates a new instance of the FeatureSampler class

Usage
FeatureSampler$new(task)
Arguments
task

(mlr3::Task) Task to sample from


Method sample()

Sample values for feature(s) from stored task

Usage
FeatureSampler$sample(feature, row_ids = NULL)
Arguments
feature

(character) Feature name(s) to sample (can be single or multiple). Must match those in the stored Task.

row_ids

(integer(): NULL) Row IDs of the stored Task to use as basis for sampling.

Returns

Modified copy of the input features with the feature(s) sampled: A data.table with same number of columns and one row matching the supplied row_ids


Method sample_newdata()

Sample values for feature(s) using external data

Usage
FeatureSampler$sample_newdata(feature, newdata)
Arguments
feature

(character) Feature name(s) to sample (can be single or multiple)

newdata

(data.table ) External data to use for sampling.


Method print()

Print sampler

Usage
FeatureSampler$print(...)
Arguments
...

Ignored.


Method clone()

The objects of this class are cloneable with this method.

Usage
FeatureSampler$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


xplainfi documentation built on Feb. 27, 2026, 1:08 a.m.