Learn R Programming

xplainfi (version 1.1.0)

rsmp_all_test: Create a resampling with all data being test data

Description

Utility for use with a pretrained learner in importance methods which support it

Usage

rsmp_all_test(task)

Value

mlr3::Resampling with an empty train_set and a single test_set identical to all of the given Task.

Arguments

task

(mlr3::Task)

Details

Note that the resulting Resampling will have an empty train set, making it useless for any other purpose than the use with a pretrained learner.

Examples

Run this code
library(mlr3)
# Create custom task from some data.frame
custom_task <- as_task_regr(mtcars, target = "mpg")
# Create matching Resampling with all-test data
resampling_custom <- rsmp_all_test(custom_task)

Run the code above in your browser using DataLab